summaryrefslogtreecommitdiff
path: root/src/api/cvc4cpp.h
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-03-17 11:19:35 -0700
committerGitHub <noreply@github.com>2021-03-17 18:19:35 +0000
commitc21a80e2f9d54596f2b1f993be4dbd271c3651aa (patch)
treedda974f90edc5df8c4f54e293c7e5869f33e63b1 /src/api/cvc4cpp.h
parentbbf9eee55db6851c0923252cdda8946030c3c75a (diff)
New C++ Api: Comprehensive guards for member functions of class Term. (#6150)
Diffstat (limited to 'src/api/cvc4cpp.h')
-rw-r--r--src/api/cvc4cpp.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/api/cvc4cpp.h b/src/api/cvc4cpp.h
index 8e7971e68..7e169a6c8 100644
--- a/src/api/cvc4cpp.h
+++ b/src/api/cvc4cpp.h
@@ -998,15 +998,15 @@ class CVC4_EXPORT Term
Sort getSort() const;
/**
- * @return the result of replacing "e" by "replacement" in this term
+ * @return the result of replacing 'term' by 'replacement' in this term
*/
- Term substitute(const Term& e, const Term& replacement) const;
+ Term substitute(const Term& term, const Term& replacement) const;
/**
* @return the result of simulatenously replacing "es" by "replacements" in
* this term
*/
- Term substitute(const std::vector<Term>& es,
+ Term substitute(const std::vector<Term>& terms,
const std::vector<Term>& replacements) const;
/**
generated by cgit on debian on lair
@@ -998,15 +998,15 @@ class CVC4_EXPORT Term
/**
- * @return the result of simulatenously replacing "es" by "replacements" in
- * this term
+ * @return the result of simulatenously replacing 'terms' by 'replacements'
+ * in this term
*/
contact matthew@masot.net with questions or feedback